build method
Creates the Service instance within the current build context.
Implementation
T build(BuildContext context) {
return create(context);
}
Creates the Service instance within the current build context.
T build(BuildContext context) {
return create(context);
}