cancel method
void
cancel()
Unbinds the listener from the service, stopping any future update notifications.
Implementation
void cancel() => service.removeListener(listener);
Unbinds the listener from the service, stopping any future update notifications.
void cancel() => service.removeListener(listener);