dispose method
void
dispose()
Cancels the subscription and releases all resources associated with the service.
Implementation
void dispose() {
cancel();
service.dispose();
}
Cancels the subscription and releases all resources associated with the service.
void dispose() {
cancel();
service.dispose();
}