StateId class

Identifies state by its optional owning element, type, and optional key.

A null element identifies state shared across a StateScope.

Constructors

StateId({required Element? element, required Key? key, required Type type})
const

Properties

element Element?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type Type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited