cancel method
void
cancel()
Unbinds the listener from the notifier, stopping future update notifications.
Implementation
void cancel() => notifier.removeListener(listener);
Unbinds the listener from the notifier, stopping future update notifications.
void cancel() => notifier.removeListener(listener);