dispose method
void
dispose()
Cancels the subscription and releases all resources associated with the state.
Implementation
void dispose() {
cancel();
notifier.dispose();
onDispose?.call(notifier.value);
}
Cancels the subscription and releases all resources associated with the state.
void dispose() {
cancel();
notifier.dispose();
onDispose?.call(notifier.value);
}