onDispose property
dynamic Function(T)?
onDispose
final
The callback invoked with the current state value when this subscription is disposed.
Implementation
final Function(T)? onDispose;
The callback invoked with the current state value when this subscription is disposed.
final Function(T)? onDispose;