mvvm_service library

Classes

Service<T>
An abstract class that represents the ViewModel in the MVVM architecture pattern. Primarily responsible for data loading and state management.
ServiceScope
A widget that hosts the ServiceScopeElement to manage and provide application-wide services down the widget subtree.
ServiceScopeElement
ServiceSubscription
Manages the connection between a Service and the elements depending on it.
StateId
Uniquely identifies a state by its type and optional key.
StateScope
A widget that hosts the StateScopeElement to manage and provide application-wide state down the widget subtree.
StateScopeElement
StateSubscription<T>
Manages the connection between a state and the elements depending on it.

Enums

ServiceMode
Controls whether serviceOf only reads a service or also watches it for changes.
ServiceStatus
Signature for the data loading state of a standard Service.
StateMode
Controls whether stateOf only reads a state or also watches it for changes.

Extensions

ServiceBuildContext on BuildContext
Provides convenience methods on BuildContext to retrieve, manage, and react to application-wide services and state.
ServiceWhen on Service<T>
Extension that provides a Flutter widget builder for Service states.