MultiServiceContainer class

A widget that acts as a container for multiple Service instances, managing their lifecycles and rebuilding the UI on updates.

The MultiServiceContainer automatically creates the services using the provided entries and calls Service.load for each service when initialized.

MultiServiceContainer(
  entries: [
    ServiceEntry((context) => MyService1()),
    ServiceEntry((context) => MyService2()),
  ],
  builder: (context) {
    final service1 = Service.of<MyService1>(context);
    final service2 = Service.of<MyService2>(context);
    return Text('${service1.value}, ${service2.value}');
  },
)
Inheritance

Constructors

MultiServiceContainer({Key? key, required List<ServiceEntry<Service>> entries, required WidgetBuilder builder})
const

Properties

builder WidgetBuilder
A builder function that creates a widget using the service.
final
entries List<ServiceEntry<Service>>
A list of service entries.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MultiServiceContainer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited