ServiceEntry<T extends Service> class
A typed entry that holds a Service instance for ServiceProvider.
Constructors
-
ServiceEntry(ServiceFactory<
T> create) -
const
Properties
-
create
→ ServiceFactory<
T> -
The Service instance being provided.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Type
-
The type used to identify the Service instance.
no setter
Methods
-
build(
BuildContext context) → T - Creates the Service instance within the current build context.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited