ServiceMode enum
Controls whether serviceOf only reads a service or also watches it for changes.
Values
- read → const ServiceMode
-
Retrieves the service instance without subscribing to its updates. The dependent widget will not rebuild when the service changes.
- watch → const ServiceMode
-
Retrieves the service and subscribes to its updates. The dependent widget will automatically rebuild whenever the service notifies listeners.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ServiceMode> - A constant List of the values in this enum, in order of their declaration.