widgets/service_container library
Classes
-
ServiceContainer<
T extends Service> - A widget that acts as a container for a Service instance, managing its lifecycle and rebuilding the UI on updates.
-
ServiceContainerState<
T extends Service> - State for a ServiceContainer widget.
Typedefs
-
ServiceFactory<
T extends Service> = T Function(BuildContext context) -
Signature for a function that creates a Service instance.
Typically used to provide a service to a
ServiceBuilder. -
ServiceWidgetBuilder<
T extends Service> = Widget Function(BuildContext context, T service) - Signature for a function that creates a widget using the given Service instance.